import { either as E } from 'fp-ts';
import { type AstNode, type DiagnosticInfo } from 'langium';
export interface ExecutionErrorDetails<N extends AstNode = AstNode> {
    message: string;
    diagnostic: DiagnosticInfo<N>;
}
/**
 * Convenience interfaces and methods wrapping {@link Either} of fp-ts library.
 * Left is the {@link ExecutionErrorDetails}
 * Right is a generic T
 */
export type Result<T> = E.Either<ExecutionErrorDetails, T>;
export type Err = E.Left<ExecutionErrorDetails>;
export type Ok<T> = E.Right<T>;
/**
 * Creates an {@link Ok} object from a data object typed T.
 * @param data the data object
 * @returns the created {@link Ok} object
 */
export declare function ok<T>(data: T): Result<T>;
/**
 * Creates an {@link Err} object from a {@link ExecutionErrorDetails} object.
 * @param details the {@link ExecutionErrorDetails} object
 * @returns the created {@link Err} object
 */
export declare function err<T>(details: ExecutionErrorDetails): Result<T>;
/**
 * Type guard for {@link Ok}
 */
export declare function isOk<T>(result: Result<T>): result is Ok<T>;
/**
 * Type guard for {@link Err}
 */
export declare function isErr<T>(result: Result<T>): result is Err;
/**
 * Convenience method to get wrapped data of an {@link Ok} object.
 */
export declare function okData<T>(ok: Ok<T>): T;
