import { type BlockDefinition, type ConstraintDefinition, type EvaluationContext, type InternalValueRepresentation, type PipelineDefinition, type PropertyAssignment, type TransformDefinition, type ValueType, type ValueTypeProvider, type WrapperFactoryProvider } from '@jvalue/jayvee-language-server';
import { type JayveeConstraintExtension } from './constraints';
import { type DebugGranularity, type DebugTargets } from './debugging/debug-configuration';
import { type JayveeExecExtension } from './extension';
import { type Logger } from './logging/logger';
export type StackNode = BlockDefinition | ConstraintDefinition | TransformDefinition;
export declare class ExecutionContext {
    readonly pipeline: PipelineDefinition;
    readonly executionExtension: JayveeExecExtension;
    readonly constraintExtension: JayveeConstraintExtension;
    readonly logger: Logger;
    readonly wrapperFactories: WrapperFactoryProvider;
    readonly valueTypeProvider: ValueTypeProvider;
    readonly runOptions: {
        isDebugMode: boolean;
        debugGranularity: DebugGranularity;
        debugTargets: DebugTargets;
    };
    readonly evaluationContext: EvaluationContext;
    private readonly stack;
    constructor(pipeline: PipelineDefinition, executionExtension: JayveeExecExtension, constraintExtension: JayveeConstraintExtension, logger: Logger, wrapperFactories: WrapperFactoryProvider, valueTypeProvider: ValueTypeProvider, runOptions: {
        isDebugMode: boolean;
        debugGranularity: DebugGranularity;
        debugTargets: DebugTargets;
    }, evaluationContext: EvaluationContext);
    enterNode(node: StackNode): void;
    exitNode(node: StackNode): void;
    /**
     * @returns the latest stack node. Returns the pipeline if the stack is empty.
     */
    getCurrentNode(): StackNode | PipelineDefinition;
    private updateLoggingContext;
    getPropertyValue<I extends InternalValueRepresentation>(propertyName: string, valueType: ValueType<I>): I;
    getProperty(propertyName: string): PropertyAssignment | undefined;
    getOrFailProperty(propertyName: string): PropertyAssignment;
    private getDefaultPropertyValue;
    private getWrapperOfCurrentNode;
}
