import { type AstNode, type DiagnosticInfo, type LangiumDocument } from 'langium';
import * as ls from 'vscode-languageserver';
export declare enum DiagnosticSeverity {
    ERROR = "error",
    WARNING = "warning",
    INFO = "info",
    HINT = "hint",
    DEBUG = "debug"
}
export interface LogEntry {
    severity: DiagnosticSeverity;
    message: string;
}
export declare abstract class Logger {
    abstract setLoggingContext(loggingContext: string | undefined): void;
    abstract setLoggingDepth(depth: number): void;
    abstract logInfo(message: string): void;
    abstract logDebug(message: string): void;
    abstract logErr(message: string): void;
    protected abstract logDiagnostic(severity: DiagnosticSeverity, message: string, range: ls.Range, document: LangiumDocument): void;
    protected logLangiumDiagnostic<N extends AstNode>(severity: DiagnosticSeverity, message: string, diagnostic: DiagnosticInfo<N>): void;
    logErrDiagnostic<N extends AstNode>(message: string, diagnostic: DiagnosticInfo<N>): void;
    logWarnDiagnostic<N extends AstNode>(message: string, diagnostic: DiagnosticInfo<N>): void;
    logInfoDiagnostic<N extends AstNode>(message: string, diagnostic: DiagnosticInfo<N>): void;
    logHintDiagnostic<N extends AstNode>(message: string, diagnostic: DiagnosticInfo<N>): void;
    logLanguageServerDiagnostic(lsDiagnostic: ls.Diagnostic, document: LangiumDocument): void;
    private toDiagnosticSeverity;
}
