import { IOType } from '@jvalue/jayvee-language-server';
import { type FileSystem } from './filesystem';
import { FileSystemFile } from './filesystem-node-file';
import { type IoTypeVisitor } from './io-type-implementation';
export declare class InMemoryFileSystem implements FileSystem {
    readonly ioType = IOType.FILE_SYSTEM;
    private rootDirectory;
    private static PATH_SEPARATOR;
    private static CURRENT_DIR;
    private static PARENT_DIR;
    /**
     * Retrieves a file from the file system. Parent directory indicators (../) are resolved to up to root
     * @function getFile
     * @param {string} path - The absolute path to the file starting with "/..."
     * @returns {FileSystemFile<unknown> | null} - The file or null if the node does not exist.
     */
    getFile(path: string): FileSystemFile<unknown> | null;
    /**
     * Saves a file to the file system.
     * @function putNode
     * @param {string} path - The absolute path to the file starting with "/..."
     * @param { FileSystemFile<unknown>} file - The file to save.
     * @returns {FileSystem | null} - The FileSystem where file was inserted or null if the file failed to insert
     */
    putFile(path: string, file: FileSystemFile<unknown>): FileSystem | null;
    static getPathSeparator(): string;
    private processPath;
    acceptVisitor<R>(visitor: IoTypeVisitor<R>): R;
}
