import { FileSystemNode } from './filesystem-node';
export declare abstract class FileSystemFile<T> extends FileSystemNode {
    /**
     * The name of the file with extension
     * @property {string} name
     */
    readonly name: string;
    /**
     * The file extension in lower case, NONE / empty string for unknown or missing file extensions.
     * @property {FileExtension} extension
     */
    readonly extension: FileExtension;
    /**
     * The MIME type of the file taken from the Content-Type header (for HTTP requests only),
     * Otherwise inferred from the file extension, default application/octet-stream for unknown or missing file extensions.
     * @property {MimeType} mimeType
     */
    readonly mimeType: MimeType;
    readonly content: T;
    constructor(
    /**
     * The name of the file with extension
     * @property {string} name
     */
    name: string, 
    /**
     * The file extension in lower case, NONE / empty string for unknown or missing file extensions.
     * @property {FileExtension} extension
     */
    extension: FileExtension, 
    /**
     * The MIME type of the file taken from the Content-Type header (for HTTP requests only),
     * Otherwise inferred from the file extension, default application/octet-stream for unknown or missing file extensions.
     * @property {MimeType} mimeType
     */
    mimeType: MimeType, content: T);
    getNode(pathParts: string[]): FileSystemNode | null;
    putNode(path: string[]): FileSystemNode | null;
    toDirectoryString(indentation: number): string;
}
/**
 * An enumeration of common file extensions. New extensions for Files need to be registered here.
 *
 * @enum {string}
 */
export declare enum FileExtension {
    ZIP = "zip",
    TXT = "txt",
    CSV = "csv",
    NONE = ""
}
/**
 * An enumeration of common MIME types.
 *
 * @enum {string}
 */
export declare enum MimeType {
    APPLICATION_ZIP = "application/zip",
    APPLICATION_OCTET_STREAM = "application/octet-stream",
    TEXT_CSV = "text/csv",
    TEXT_PLAIN = "text/plain"
}
