import { type AstNode, type Reference } from 'langium';
import { type OperatorEvaluatorRegistry } from '../expressions';
import { type BlockTypePipeline, type BuiltinConstrainttypeDefinition, type CellRangeLiteral, type CompositeBlockTypeDefinition, type PipeDefinition, type PipelineDefinition, type ReferenceableBlockTypeDefinition, type ValueTypeReference, type ValuetypeDefinition } from '../generated/ast';
import { type AstNodeWrapper } from './ast-node-wrapper';
import { CellRangeWrapper } from './cell-range-wrapper';
import { PipeWrapper } from './pipe-wrapper';
import { PipelineWrapper } from './pipeline-wrapper';
import { BlockTypeWrapper } from './typed-object/block-type-wrapper';
import { ConstraintTypeWrapper } from './typed-object/constrainttype-wrapper';
import { type PrimitiveValueType, type ValueType } from './value-type';
import { CollectionValueType } from './value-type/primitive/collection/collection-value-type';
import { type ValueTypeProvider } from './value-type/primitive/primitive-value-type-provider';
declare abstract class AstNodeWrapperFactory<N extends AstNode, W extends AstNodeWrapper<N>> {
    abstract canWrap(toBeWrapped: N | Reference<N>): boolean;
    abstract doWrap(toBeWrapped: N | Reference<N>): W;
    wrap(toBeWrapped: N | Reference<N>): W;
    private getName;
}
export declare class WrapperFactoryProvider {
    private readonly operatorEvaluatorRegistry;
    private readonly primitiveValueTypeContainer;
    readonly BlockType: BlockTypeWrapperFactory;
    readonly ConstraintType: ConstraintTypeWrapperFactory;
    readonly Pipeline: PipelineWrapperFactory;
    readonly Pipe: PipeWrapperFactory;
    readonly CellRange: CellRangeWrapperFactory;
    readonly TypedObject: TypedObjectWrapperFactory;
    readonly ValueType: ValueTypeWrapperFactory;
    constructor(operatorEvaluatorRegistry: OperatorEvaluatorRegistry, primitiveValueTypeContainer: ValueTypeProvider);
}
declare class CellRangeWrapperFactory extends AstNodeWrapperFactory<CellRangeLiteral, CellRangeWrapper> {
    canWrap(toBeWrapped: CellRangeLiteral): boolean;
    doWrap(toBeWrapped: CellRangeLiteral): CellRangeWrapper;
}
declare class BlockTypeWrapperFactory extends AstNodeWrapperFactory<ReferenceableBlockTypeDefinition, BlockTypeWrapper> {
    private readonly operatorEvaluatorRegistry;
    private readonly valueTypeProvider;
    private readonly wrapperFactories;
    constructor(operatorEvaluatorRegistry: OperatorEvaluatorRegistry, valueTypeProvider: ValueTypeProvider, wrapperFactories: WrapperFactoryProvider);
    canWrap(toBeWrapped: ReferenceableBlockTypeDefinition | Reference<ReferenceableBlockTypeDefinition>): boolean;
    doWrap(toBeWrapped: ReferenceableBlockTypeDefinition | Reference<ReferenceableBlockTypeDefinition>): BlockTypeWrapper;
}
declare class ConstraintTypeWrapperFactory extends AstNodeWrapperFactory<BuiltinConstrainttypeDefinition, ConstraintTypeWrapper> {
    private readonly operatorEvaluatorRegistry;
    private readonly valueTypeProvider;
    private readonly wrapperFactories;
    constructor(operatorEvaluatorRegistry: OperatorEvaluatorRegistry, valueTypeProvider: ValueTypeProvider, wrapperFactories: WrapperFactoryProvider);
    canWrap(toBeWrapped: BuiltinConstrainttypeDefinition | Reference<BuiltinConstrainttypeDefinition>): boolean;
    doWrap(toBeWrapped: BuiltinConstrainttypeDefinition | Reference<BuiltinConstrainttypeDefinition>): ConstraintTypeWrapper;
}
declare class PipelineWrapperFactory extends AstNodeWrapperFactory<PipelineDefinition | CompositeBlockTypeDefinition, PipelineWrapper<PipelineDefinition | CompositeBlockTypeDefinition>> {
    private pipeWrapperFactory;
    constructor(pipeWrapperFactory: IPipeWrapperFactory);
    canWrap(toBeWrapped: PipelineDefinition | CompositeBlockTypeDefinition): boolean;
    wrap<T extends PipelineDefinition | CompositeBlockTypeDefinition>(// override to adjust typing
    toBeWrapped: T | Reference<T>): PipelineWrapper<T>;
    doWrap<T extends PipelineDefinition | CompositeBlockTypeDefinition>(toBeWrapped: T): PipelineWrapper<T>;
}
export interface IPipeWrapperFactory {
    canWrap(toBeWrapped: PipeDefinition | BlockTypePipeline, chainIndex: number): boolean;
    wrap<T extends PipeDefinition | BlockTypePipeline>(toBeWrapped: T, chainIndex: number): PipeWrapper<T>;
    doWrap<T extends PipeDefinition | BlockTypePipeline>(toBeWrapped: T, chainIndex: number): PipeWrapper<T>;
    wrapAll<T extends PipeDefinition | BlockTypePipeline>(toBeWrapped: T): PipeWrapper<T>[];
}
declare class PipeWrapperFactory implements IPipeWrapperFactory {
    canWrap(toBeWrapped: PipeDefinition | BlockTypePipeline, chainIndex: number): boolean;
    wrap<T extends PipeDefinition | BlockTypePipeline>(toBeWrapped: T, chainIndex: number): PipeWrapper<T>;
    doWrap<T extends PipeDefinition | BlockTypePipeline>(toBeWrapped: T, chainIndex: number): PipeWrapper<T>;
    wrapAll<T extends PipeDefinition | BlockTypePipeline>(toBeWrapped: T): PipeWrapper<T>[];
}
declare class TypedObjectWrapperFactory {
    private readonly blockTypeWrapperFactory;
    private readonly constraintTypeWrapperFactory;
    constructor(blockTypeWrapperFactory: BlockTypeWrapperFactory, constraintTypeWrapperFactory: ConstraintTypeWrapperFactory);
    /**
     * Creates a wrapper for the typed object.
     * Returns undefined if wrapping is not possible (does not throw an error).
     */
    wrap(toBeWrapped: Reference<ReferenceableBlockTypeDefinition> | Reference<BuiltinConstrainttypeDefinition> | BuiltinConstrainttypeDefinition | ReferenceableBlockTypeDefinition | undefined): BlockTypeWrapper | ConstraintTypeWrapper | undefined;
}
declare class ValueTypeWrapperFactory {
    private readonly wrapperFactories;
    private readonly primitiveValueTypeProvider;
    constructor(wrapperFactories: WrapperFactoryProvider, primitiveValueTypeProvider: ValueTypeProvider);
    wrap(identifier: ValuetypeDefinition | ValueTypeReference | undefined): ValueType | undefined;
    wrapCollection(collectionRef: ValueTypeReference): CollectionValueType;
    wrapPrimitive(builtinValuetype: ValuetypeDefinition): PrimitiveValueType | undefined;
}
export {};
