import { type DeepPartial, type Module } from 'langium';
import { type DefaultSharedModuleContext, type LangiumServices, type LangiumSharedServices, type PartialLangiumServices } from 'langium/lsp';
import { type OperatorEvaluatorRegistry, type OperatorTypeComputerRegistry } from './ast/expressions/operator-registry';
import { ValueTypeProvider } from './ast/wrappers/value-type/primitive/primitive-value-type-provider';
import { WrapperFactoryProvider } from './ast/wrappers/wrapper-factory-provider';
import { JayveeImportResolver } from './services/import-resolver';
import { RuntimeParameterProvider } from './services/runtime-parameter-provider';
import { JayveeValidationRegistry } from './validation/validation-registry';
/**
 * Declaration of custom services for the Jayvee language.
 * https://langium.org/docs/configuration-services/#adding-new-services
 */
export interface JayveeAddedServices {
    RuntimeParameterProvider: RuntimeParameterProvider;
    operators: {
        TypeComputerRegistry: OperatorTypeComputerRegistry;
        EvaluatorRegistry: OperatorEvaluatorRegistry;
    };
    ValueTypeProvider: ValueTypeProvider;
    WrapperFactories: WrapperFactoryProvider;
    validation: {
        ValidationRegistry: JayveeValidationRegistry;
    };
    ImportResolver: JayveeImportResolver;
}
/**
 * Union of Langium default services and your custom services - use this as constructor parameter
 * of custom service classes.
 */
export type JayveeServices = LangiumServices & JayveeAddedServices;
export type JayveeSharedServices = LangiumSharedServices;
/**
 * Dependency injection module that overrides Langium default services and contributes the
 * declared custom services. The Langium defaults can be partially specified to override only
 * selected services, while the custom services must be fully specified.
 */
export declare const JayveeModule: Module<JayveeServices, PartialLangiumServices & JayveeAddedServices>;
export declare const JayveeSharedModule: Module<JayveeSharedServices, DeepPartial<JayveeSharedServices>>;
/**
 * Create the full set of services required by Langium.
 *
 * First inject the shared services by merging two modules:
 *  - Langium default shared services
 *  - Services generated by langium-cli
 *
 * Then inject the language-specific services by merging three modules:
 *  - Langium default language-specific services
 *  - Services generated by langium-cli
 *  - Services specified in this file
 *
 * @param context Optional module context with the LSP connection
 * @returns An object wrapping the shared services and the language-specific services
 */
export declare function createJayveeServices(context: DefaultSharedModuleContext): {
    shared: LangiumSharedServices;
    Jayvee: JayveeServices;
};
